#
# spec file for package cura-lulzbot
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           cura-lulzbot
Version:        3.2.20
Release:        lp150.1.1
Summary:        3D printer control software
License:        AGPL-3.0-only
Group:          Hardware/Printing
Url:            https://code.alephobjects.com/source/cura-lulzbot.git
Source0:        %name-%{version}.tar.xz
# PATCH-FIX-OPENSUSE fix-build.patch -- adapt SUSE python install path
Patch1:         fix-build.patch
# PATCH-FIX-OPENSUSE CuraEngine-lulzbot.patch -- use lulzbot variant of CuraEngine by default
Patch2:         CuraEngine-lulzbot.patch
BuildArch:      noarch
Provides:       cura2-lulzbot
Obsoletes:      cura2-lulzbot < 3
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  icoutils
BuildRequires:  python3-devel
BuildRequires:  update-desktop-files
BuildRequires:  uranium-lulzbot
Requires:       cura-engine-lulzbot = %version
Requires:       uranium-lulzbot
# dependency scripts do not find qtquickcontrols automatically
Requires:       libqt5-qtquickcontrols
Requires:       python3-numpy
Requires:       python3-opengl
Requires:       python3-power
Requires:       python3-pyserial
Requires:       python3-qt5
Requires:       python3-scipy
Requires:       python3-sip
Requires:       python3-zeroconf

# There is a hardcoded version to the firmware in the code :/ 
Requires:       uranium-firmware-lulzbot = %( tar xf %{S:0} --wildcards \*/USBPrinterOutputDeviceManager.py --to-command='sed -n -e "s,.*Marlin_Mini_SingleExtruder_\([^_]*_[^_]*\).hex.*,\1,p"' )

%description
Cura is a software solution for 3D printing.
While it is developed to be used with the Ultimaker 3D printer, it can be used
with other RepRap based designs.

Cura helps in setting up an Ultimaker, shows 3D models, allows for scaling /
positioning, can slice the model to G-Code, has editable configuration
settings, and send this G-Code to the 3D printer for printing.

%prep
%setup -q
%patch1 -p1
%patch2 -p1

%build
%cmake -DURANIUM_DIR=/usr/lib/uranium -DURANIUM_SCRIPTS_DIR=/usr/share/uranium/resources/scripts \
       -DCURA_VERSION=%version \
       -DCURA_BUILDTYPE=release
make %{?_smp_mflags}

%install
cd build
%make_install
%suse_update_desktop_file cura-lulzbot Graphics 3DGraphics
sed -i -e 's,^Exec=.*,Exec=cura-lulzbot %F,' \
       -e 's,^#!/usr/bin/env.*,#!/usr/bin/python3,' \
    %{buildroot}%{_datadir}/applications/cura-lulzbot.desktop
%fdupes %buildroot

%files
%defattr (-,root,root,-)
%doc LICENSE README.md
%{python3_sitelib}/cura
%{_datadir}/cura
%{_datadir}/applications/cura-lulzbot.desktop
%{_datadir}/mime/packages/cura.xml
%{_datadir}/appdata/cura.appdata.xml
%{_bindir}/cura-lulzbot
/usr/lib/cura

%changelog
* Mon May 14 2018 adrian@suse.de
- update to version 3.2.20
  * Changed Marlin FW to v1.1.8.51
  * minor bugfixes
* Wed May  2 2018 adrian@suse.de
- update to version 3.2.19
  * Changed Marlin FW to v1.1.8.42
  * Mini 2 support (former Hibiscus)
  * various printer fixes
* Thu Apr 19 2018 adrian@suse.de
- update to version 3.2.18
  * Changed Marlin FW to vv1.1.8.29
  * various printer fixes
* Mon Mar 26 2018 adrian@suse.de
- update to version 3.2.16
  * Changed Marlin FW to v1.1.8.21
  * fixed profiles filter in preferences page
  * fix bed pre-heat button
  * updating Polylite Standard print temp
  * Further UI and material updates
- compile in cura version
* Thu Mar  8 2018 adrian@suse.de
- update to version 3.2.9
  * Updates for various printers
* Wed Jan 31 2018 jengelh@inai.de
- Say what the package does, not what it aims to do in future.
* Wed Jan 31 2018 adrian@suse.de
- update to version 3.2.1
  * entire rewrite
  * supports network and headless mode
- Patches:
  dynamic-linking.patch was never applied on the package, but
    factory check scripts got confused due
    to rename
  fix-build.patch: adapt SUSE python installation pathes
  CuraEngine-lulzbot.patch: Find the LulzBot CuraEngine by default
* Wed Jan  3 2018 adrian@suse.de
- fix license tag
* Fri Sep  8 2017 adrian@suse.de
- fix startup crash due to missing libglut3
* Tue Jul 25 2017 jengelh@inai.de
- Fix grammatical errors.
* Mon Jul 24 2017 adrian@suse.de
- update to version 21.06
  * use original upstream tar ball
  * clone curaengine via source service since it is not included anymore
* Mon Jun 26 2017 adrian@suse.de
- avoid conflicts with cura 2
- link CuraEngine dynamic
- open documentation using xdg-open instead of hardcoded Firefox
* Wed Jun 21 2017 adrian@suse.de
- initial package based on upstream package for Fedora
